@@ -6,6 +6,7 @@ from .v3.devices import Devices
 from .v3.domains import Domains
 from .v3.data_model import DataModel
 from .v3.device_monitoring import DeviceMonitoring
+from .v3.sessions import Sessions
 from .v3.setting_values import SettingValues
 from .v3.task_templates import TaskTemplates
 from .v3.tasks import Tasks
@@ -40,6 +41,7 @@ class Coiote:
         self.device_monitoring: DeviceMonitoring = self._make_module(DeviceMonitoring)
         self.devices: Devices = self._make_module(Devices)
         self.domains: Domains = self._make_module(Domains)
+        self.sessions: Sessions = self._make_module(Sessions)
         self.setting_values: SettingValues = self._make_module(SettingValues)
         self.task_reports: TaskReports = self._make_module(TaskReports)
         self.task_templates: TaskTemplates = self._make_module(TaskTemplates)
